==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: KeyMakingDlg.h <==
#if !defined(AFX_KEYMAKINGDLG_H__F789172E_B87F_457F_B5D5_0813F27E4EBB__INCLUDED_)
#define AFX_KEYMAKINGDLG_H__F789172E_B87F_457F_B5D5_0813F27E4EBB__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// KeyMakingDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CKeyMakingDlg dialog

class CKeyMakingDlg : public CDialog
{
// Construction
public:
	CKeyMakingDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );

// Dialog Data
	unsigned long		m_lMaxSize;
	unsigned long		m_lCurSize;
	int					m_nPrevPer;
	CString				m_strPath; 
	CString				m_strPer;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	BOOL			m_bIsFirst;
	//{{AFX_DATA(CKeyMakingDlg)
	CStatic	m_staticPath;
	CStatic	m_staticPer;
//	enum { IDD = IDD_KEY_MAKING_DIALOG };
	enum { IDD = 139 };

		// NOTE: the ClassWizard will add data members here
	//}}AFX_DATA

	void SetMaxSize( unsigned long nMaxSize );
	void SetCurSize( unsigned long nCurSize ); 
	void SetCurPath( char* szpath );
	void PrintProgress();
	void PrintPath();
	void PrintSize();
	void SetDefault();

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CKeyMakingDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CKeyMakingDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg void OnTimer(UINT nIDEvent);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_KEYMAKINGDLG_H__F789172E_B87F_457F_B5D5_0813F27E4EBB__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-1.2.0-1.zip: KeyMakingDlg.h <==
#if !defined(AFX_KEYMAKINGDLG_H__F789172E_B87F_457F_B5D5_0813F27E4EBB__INCLUDED_)
#define AFX_KEYMAKINGDLG_H__F789172E_B87F_457F_B5D5_0813F27E4EBB__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// KeyMakingDlg.h : header file
//

/////////////////////////////////////////////////////////////////////////////
// CKeyMakingDlg dialog

class CKeyMakingDlg : public CDialog
{
// Construction
public:
	CKeyMakingDlg(CWnd* pParent = NULL);   // standard constructor
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	void DrawReliability ( CDC* pDC );
	int MyRound( double i );

// Dialog Data
	unsigned long		m_lMaxSize;
	unsigned long		m_lCurSize;
	int					m_nPrevPer;
	CString				m_strPath; 
	CString				m_strPer;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	BOOL			m_bIsFirst;
	BOOL			m_bDrawing;
	//{{AFX_DATA(CKeyMakingDlg)
	CStatic	m_staticPath;
	CStatic	m_staticPer;
//	enum { IDD = IDD_KEY_MAKING_DIALOG };
	enum { IDD = 139 };

		// NOTE: the ClassWizard will add data members here
	//}}AFX_DATA

	void SetMaxSize( unsigned long nMaxSize );
	void SetCurSize( unsigned long nCurSize ); 
	void SetCurPath( char* szpath );
	void PrintProgress();
	void PrintPath();
	void PrintSize();
	void SetDefault();

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CKeyMakingDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CKeyMakingDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_KEYMAKINGDLG_H__F789172E_B87F_457F_B5D5_0813F27E4EBB__INCLUDED_)
